@@ -2,8 +2,10 @@ package Minion::Command::minion::job;
 use Mojo::Base 'Mojolicious::Command';
 
 use Getopt::Long qw(GetOptionsFromArray :config no_auto_abbrev no_ignore_case);
-use Mango::BSON 'bson_oid';
+use Mango::BSON qw(bson_oid bson_time);
+use Mojo::JSON 'decode_json';
 use Mojo::Util 'dumper';
+use Time::Piece 'localtime';
 
 has description => 'Manage Minion jobs.';
 has usage => sub { shift->extract_usage };
@@ -11,12 +13,22 @@ has usage => sub { shift->extract_usage };
 sub run {
   my ($self, @args) = @_;
 
+  my $args    = [];
+  my $options = {};
   GetOptionsFromArray \@args,
-    'r|remove'  => \my $remove,
-    'R|restart' => \my $restart,
-    's|stats'   => \my $stats;
+    'a|args=s' => sub { $args = decode_json($_[1]) },
+    'd|delayed=i' => sub { $options->{delayed} = bson_time($_[1] * 1000) },
+    'e|enqueue=s'  => \my $enqueue,
+    'p|priority=i' => sub { $options->{priority} = $_[1] },
+    'r|remove'     => \my $remove,
+    'R|restart'    => \my $restart,
+    's|stats'      => \my $stats;
   my $oid = @args ? bson_oid(shift @args) : undef;
 
+  # Enqueue
+  return say $self->app->minion->enqueue($enqueue, $args, $options)
+    if $enqueue;
+
   # Show stats or list jobs
   return $stats ? $self->_stats : $self->_list unless $oid;
   die "Job does not exist.\n" unless my $job = $self->app->minion->job($oid);
@@ -35,23 +47,27 @@ sub _info {
   my ($self, $job) = @_;
 
   # Details
-  print $job->task, ' (', $job->state, ")\n", dumper($job->args);
+  my $state    = $job->state;
+  my $priority = $job->priority;
+  my $restarts = $job->restarts;
+  print $job->task, " ($state, p$priority, r$restarts)\n", dumper($job->args);
   my $err = $job->error;
-  say $err if $err;
+  say chomp $err ? $err : $err if $err;
 
   # Timing
-  my @times   = ('Created: ' . $job->created);
+  say localtime($job->created)->datetime, ' (created)';
+  my $delayed = $job->delayed;
+  say localtime($delayed)->datetime, ' (delayed)' if $delayed > time;
   my $started = $job->started;
-  push @times, 'Started: ' . $started if $started;
+  say localtime($started)->datetime, ' (started)' if $started;
   my $finished = $job->finished;
-  push @times, 'Finished: ' . $finished if $finished;
-  say join '  ', @times;
+  say localtime($finished)->datetime, ' (finished)' if $finished;
 }
 
 sub _list {
   my $cursor = shift->app->minion->jobs->find->sort({_id => -1});
   while (my $doc = $cursor->next) {
-    say sprintf '%s  %8s  %s', @$doc{qw(_id state task)};
+    say sprintf '%s  %-8s  %s', @$doc{qw(_id state task)};
   }
 }
 
@@ -78,14 +94,20 @@ Minion::Command::minion::job - Minion job command
   Usage: APPLICATION minion job [ID]
 
     ./myapp.pl minion job
+    ./myapp.pl minion job -e foo -a '[23, "bar"]'
+    ./myapp.pl minion job -e foo -p 5
     ./myapp.pl minion job -s
     ./myapp.pl minion job 533b4e2b5867b4c72b0a0000
     ./myapp.pl minion job 533b4e2b5867b4c72b0a0000 -r
 
   Options:
-    -r, --remove    Remove job.
-    -R, --restart   Restart job.
-    -s, --stats     Show queue statistics.
+    -a, --args <JSON array>   Arguments for new job in JSON format.
+    -d, --delayed <epoch>     Delay new job until after this point in time.
+    -e, --enqueue <name>      New job to be enqueued.
+    -p, --priority <number>   Priority of new job, defaults to 0.
+    -r, --remove              Remove job.
+    -R, --restart             Restart job.
+    -s, --stats               Show queue statistics.
 
 =head1 DESCRIPTION
 
